import 'package:eufemia/palette.dart';
import 'package:eufemia/spacing.dart';
import 'package:flutter/material.dart';

export '../extensions/snack.dart';

/// {@category Components}
/// Wrapper around [SnackBar] helper methods.
class Snacks {
  /// The context in which the SnackBar should be shown.
  final BuildContext context;

  Snacks(this.context);

  /// Returns a [SnackBar] from the given parameters.
  SnackBar bar({
    /// The title widget.
    @required Widget title,

    /// The left-side leading widget, often an icon.
    Widget leading,

    /// The label for the right-side action.
    String actionLabel,

    /// The function to call when the bar is tapped.
    VoidCallback onTap,

    /// The duration of which to show the bar.
    Duration duration,

    /// If the bar should be hidden on tap.
    bool hideOnTap = true,
  }) {
    final palette = EufemiaPalette.of(context);
    SnackBarAction action;

    if (actionLabel != null) {
      action = SnackBarAction(
        label: actionLabel,
        onPressed: () {
          onTap?.call();
          if (hideOnTap) {
            Scaffold.of(context).hideCurrentSnackBar();
          }
        },
      );
    }

    return SnackBar(
      elevation: 1,
      content: EufemiaRow(
        children: [
          if (leading != null) ...{
            EufemiaPadding.medium(
              sides: EufemiaSides.right,
              child: IconTheme(
                data: Theme.of(context).iconTheme.copyWith(
                      color: palette.onSnack,
                    ),
                child: leading,
              ),
            ),
          },
          title,
        ],
      ),
      action: action,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(2.0),
      ),
      behavior: SnackBarBehavior.floating,
      duration: duration ?? Duration(seconds: 4),
    );
  }
}
