import 'package:flutter/widgets.dart';
import 'package:provider/provider.dart';

import 'space.dart';
import 'spacing.dart';

/// {@category Spacing}
/// An empty spacing widget used to create padding or space.
class EufemiaGap extends StatelessWidget {
  final EufemiaSpace vertical;
  final EufemiaSpace horizontal;
  final EufemiaSpace space;

  const EufemiaGap(
    this.space, {
    Key key,
  })  : vertical = null,
        horizontal = null,
        super(key: key);

  /// Creates an [EufemiaGap] instance of [EufemiaSpace.extraSmall] size.
  const EufemiaGap.extraSmall({
    Key key,
  })  : space = EufemiaSpace.extraSmall,
        vertical = null,
        horizontal = null,
        super(key: key);

  /// Creates an [EufemiaGap] instance of [EufemiaSpace.small] size.
  const EufemiaGap.small({
    Key key,
  })  : space = EufemiaSpace.small,
        vertical = null,
        horizontal = null,
        super(key: key);

  /// Creates an [EufemiaGap] instance of [EufemiaSpace.large] size.
  const EufemiaGap.large({
    Key key,
  })  : space = EufemiaSpace.large,
        vertical = null,
        horizontal = null,
        super(key: key);

  /// Creates an [EufemiaGap] instance of [EufemiaSpace.medium] size.
  const EufemiaGap.medium({
    Key key,
  })  : space = EufemiaSpace.medium,
        vertical = null,
        horizontal = null,
        super(key: key);

  /// Creates an [EufemiaGap] instance of [EufemiaSpace.extraLarge] size.
  const EufemiaGap.extraLarge({
    Key key,
  })  : space = EufemiaSpace.extraLarge,
        vertical = null,
        horizontal = null,
        super(key: key);

  /// Creates an [EufemiaGap] instance of [EufemiaSpace.extraExtraLarge] size.
  const EufemiaGap.extraExtraLarge({
    Key key,
  })  : space = EufemiaSpace.extraExtraLarge,
        vertical = null,
        horizontal = null,
        super(key: key);

  /// Creates an [EufemiaGap] instance which only creates spacing along the
  /// horizontal axis.
  const EufemiaGap.horizontal({
    Key key,
    this.horizontal = EufemiaSpace.medium,
  })  : assert(horizontal != null),
        vertical = EufemiaSpace.none,
        space = null,
        super(key: key);

  /// Creates an [EufemiaGap] instance which only creates spacing along the
  /// vertical axis.
  const EufemiaGap.vertical({
    Key key,
    this.vertical = EufemiaSpace.medium,
  })  : assert(vertical != null),
        horizontal = EufemiaSpace.none,
        space = null,
        super(key: key);

  @override
  Widget build(BuildContext context) {
    final spacing = EufemiaSpacing.of(context);
    var horizontal = this.horizontal;
    var vertical = this.vertical;
    if (horizontal == null && vertical == null) {
      final axis = Provider.of<Axis>(context);
      if (axis == Axis.horizontal) {
        horizontal = space;
      } else {
        vertical = space;
      }
    }
    return SizedBox(
      width: horizontal?.toPoints(data: spacing) ?? 0.0,
      height: vertical?.toPoints(data: spacing) ?? 0.0,
    );
  }
}
