import 'package:flutter/widgets.dart';

import 'insets.dart';
import 'space.dart';
import 'sides.dart';

/// {@category Spacing}
/// A widget providing its child with Eufemia-specific padding.
class EufemiaPadding extends StatelessWidget {
  /// {@macro eufemia.spacing.insets}
  final EufemiaInsets padding;

  /// {@macro flutter.widgets.child}
  final Widget child;

  const EufemiaPadding({
    Key key,
    this.child,
    this.padding = EufemiaInsets.none,
  })  : assert(padding != null),
        super(key: key);

  /// Constructs an [EufemiaPadding] instance with the given [space] applied
  /// only to the given [sides].
  factory EufemiaPadding.only(
    EufemiaSpace space, {
    Key key,
    EufemiaSides sides = EufemiaSides.all,
    Widget child,
  }) =>
      EufemiaPadding(
        key: key,
        padding: EufemiaInsets.only(space, sides),
        child: child,
      );

  /// Constructs an [EufemiaPadding] instance with [EufemiaSpace.extraSmall] applied
  /// only to the given [sides].
  factory EufemiaPadding.extraSmall({
    Key key,
    EufemiaSides sides = EufemiaSides.all,
    Widget child,
  }) =>
      EufemiaPadding(
        key: key,
        padding: EufemiaInsets.only(EufemiaSpace.extraSmall, sides),
        child: child,
      );

  /// Constructs an [EufemiaPadding] instance with [EufemiaSpace.small] applied
  /// only to the given [sides].
  factory EufemiaPadding.small({
    Key key,
    EufemiaSides sides = EufemiaSides.all,
    Widget child,
  }) =>
      EufemiaPadding(
        key: key,
        padding: EufemiaInsets.only(EufemiaSpace.small, sides),
        child: child,
      );

  /// Constructs an [EufemiaPadding] instance with [EufemiaSpace.medium] applied
  /// only to the given [sides].
  factory EufemiaPadding.medium({
    Key key,
    EufemiaSides sides = EufemiaSides.all,
    Widget child,
  }) =>
      EufemiaPadding(
        key: key,
        padding: EufemiaInsets.only(EufemiaSpace.medium, sides),
        child: child,
      );

  /// Constructs an [EufemiaPadding] instance with [EufemiaSpace.large] applied
  /// only to the given [sides].
  factory EufemiaPadding.large({
    Key key,
    EufemiaSides sides = EufemiaSides.all,
    Widget child,
  }) =>
      EufemiaPadding(
        key: key,
        padding: EufemiaInsets.only(EufemiaSpace.large, sides),
        child: child,
      );

  /// Constructs an [EufemiaPadding] instance with [EufemiaSpace.extraLarge] applied
  /// only to the given [sides].
  factory EufemiaPadding.extraLarge({
    Key key,
    EufemiaSides sides = EufemiaSides.all,
    Widget child,
  }) =>
      EufemiaPadding(
        key: key,
        padding: EufemiaInsets.only(EufemiaSpace.extraLarge, sides),
        child: child,
      );

  /// Constructs an [EufemiaPadding] instance with [EufemiaSpace.extraExtraLarge] applied
  /// only to the given [sides].
  factory EufemiaPadding.extraExtraLarge({
    Key key,
    EufemiaSides sides = EufemiaSides.all,
    Widget child,
  }) =>
      EufemiaPadding(
        key: key,
        padding: EufemiaInsets.only(EufemiaSpace.extraExtraLarge, sides),
        child: child,
      );

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: padding.toEdgeInsets(context: context),
      child: child,
    );
  }
}
