/// {@category Spacing}
/// A class defining an object which may or may not have a top,
/// bottom, left or right side.
class EufemiaSides {
  /// If the object has a top side.
  final bool hasTop;

  /// If the object has a bottom side.
  final bool hasBottom;

  /// If the object has a left side.
  final bool hasLeft;

  /// If the object has a right side.
  final bool hasRight;

  /// An instance with all four sides.
  static const EufemiaSides all = EufemiaSides(
    hasLeft: true,
    hasRight: true,
    hasTop: true,
    hasBottom: true,
  );

  /// An instance with only a top side.
  static const EufemiaSides top = EufemiaSides(
    hasTop: true,
  );

  /// An instance with only a bottom side.
  static const EufemiaSides bottom = EufemiaSides(
    hasBottom: true,
  );

  /// An instance with only a right side.
  static const EufemiaSides right = EufemiaSides(
    hasRight: true,
  );

  /// An instance with only a left side.
  static const EufemiaSides left = EufemiaSides(
    hasLeft: true,
  );

  /// An instance with all but a right side.
  static const EufemiaSides notRight = EufemiaSides(
    hasTop: true,
    hasBottom: true,
    hasLeft: true,
  );

  /// An instance with all but a top side.
  static const EufemiaSides notTop = EufemiaSides(
    hasRight: true,
    hasBottom: true,
    hasLeft: true,
  );

  /// An instance with all but a left side.
  static const EufemiaSides notLeft = EufemiaSides(
    hasRight: true,
    hasBottom: true,
    hasTop: true,
  );

  /// An instance with all but a bottom side.
  static const EufemiaSides notBottom = EufemiaSides(
    hasRight: true,
    hasLeft: true,
    hasTop: true,
  );

  /// An instance with top and bottom sides.
  static const EufemiaSides vertical = EufemiaSides(
    hasTop: true,
    hasBottom: true,
  );

  /// An instance with left and right sides.
  static const EufemiaSides horizontal = EufemiaSides(
    hasLeft: true,
    hasRight: true,
  );

  // Adds this instance with [other].
  EufemiaSides operator &(EufemiaSides other) {
    return this + other;
  }

  // Adds the values of this instance with [other].
  EufemiaSides operator +(EufemiaSides other) {
    if (other is EufemiaSides) {
      return EufemiaSides(
        hasBottom: hasBottom || other.hasBottom,
        hasRight: hasRight || other.hasRight,
        hasLeft: hasLeft || other.hasLeft,
        hasTop: hasTop || other.hasTop,
      );
    }

    return this;
  }

  /// Returns an instance where only the common sides of this and [other] are
  /// present.
  EufemiaSides operator -(EufemiaSides other) {
    return EufemiaSides(
      hasBottom: hasBottom && !other.hasBottom,
      hasRight: hasRight && !other.hasRight,
      hasLeft: hasLeft && !other.hasLeft,
      hasTop: hasTop && !other.hasTop,
    );
  }

  const EufemiaSides({
    this.hasTop = false,
    this.hasBottom = false,
    this.hasLeft = false,
    this.hasRight = false,
  })  : assert(hasTop != null),
        assert(hasBottom != null),
        assert(hasLeft != null),
        assert(hasRight != null);
}
