/// Provides font assets, typography and text styling features.
///
/// The `EufemiaTypographyData` class is a collection of text styles that are used throughout the library of components. You can create your own, but the default `fallback` styles are as specified by the Eufemia design system.
///
/// The typography provider can be accessed using
///
/// ```dart
/// final typography = EufemiaTypography.of(context)
/// ```
///
/// If using the bundled themes, fonts are automatically set up. Otherwise, specify the `fontFamily` and `package` properties:
///
/// ```dart
/// TextStyle(
///   fontFamily: 'DNB Sans',
///   package: 'eufemia',
/// )
/// ```
library typography;

export 'src/typography/family.dart';
export 'src/typography/predefined_style.dart';
export 'src/typography/size.dart';
export 'src/typography/text_style.dart';
export 'src/typography/text.dart';
export 'src/typography/typography_data_fallback.dart';
export 'src/typography/typography_data.dart';
export 'src/typography/typography.dart';
export 'src/typography/weight.dart';
export 'src/typography/height.dart';
