import 'dart:io';

import 'package:dotenv/dotenv.dart';
import 'package:figma/figma.dart';
import 'package:http/http.dart';
import 'package:recase/recase.dart';

void main() async {
  load();

  final token = env['ACCESS_TOKEN'];
  final key = env['EUFEMIA_ICONS'];
  const dir = './figma';

  final client = FigmaClient(token);

  final file = await client.getFile(key);

  final iconsFile = file.document.children.last as Canvas;

  final vectors = <Vector>[];

  iconsFile.children.whereType<Frame>().forEach((frame) {
    frame.children.whereType<Frame>().forEach((category) {
      category.children.whereType<Frame>().forEach((icon) {
        icon.children.forEach((child) {
          if (child is Frame) {
            child.children.whereType<Vector>().forEach((vector) {
              vectors.add(vector);
            });
          }
        });
      });
    });
  });

  final images = await client.getImages(
    key,
    FigmaQuery(ids: vectors.map((v) => v.id).toList(), format: 'svg'),
  );

  final icons = <Vector, String>{};

  images.images.forEach((key, value) {
    icons.addAll({
      vectors.firstWhere((v) => v.id == key): value,
    });
  });

  icons.forEach((key, value) async {
    await Directory(dir).create();
    final path = '$dir/${key.name.toLowerCase().snakeCase}.svg';
    await get(value).then((res) => File(path).writeAsBytes(res.bodyBytes));
  });

  Directory(dir).listSync().forEach((element) async {
    await Process.run('svgo', ['-i ${element.path}', '-o ${element.path}']);
  });
}
